@@ -65,6 +65,7 @@ from aea.configurations.base import (
 )
 from aea.configurations.constants import (
     DEFAULT_CONNECTION,
+    DEFAULT_LEDGER,
     DEFAULT_PROTOCOL,
     DEFAULT_SKILL,
 )
@@ -208,6 +209,7 @@ class _DependenciesManager:
         component = self._dependencies.pop(component_id)
         # remove from the index of all dependencies grouped by type
         self._all_dependencies_by_type[component_id.component_type].pop(component_id)
+
         if len(self._all_dependencies_by_type[component_id.component_type]) == 0:
             self._all_dependencies_by_type.pop(component_id.component_type)
         # remove from prefix to id index
@@ -236,14 +238,6 @@ class _DependenciesManager:
             )
         return all_pypi_dependencies
 
-    @staticmethod
-    def _build_dotted_part(component, relative_import_path) -> str:
-        """Given a component, build a dotted path for import."""
-        if relative_import_path == "":
-            return component.prefix_import_path
-        else:
-            return component.prefix_import_path + "." + relative_import_path
-
 
 class AEABuilder:
     """
@@ -302,7 +296,7 @@ class AEABuilder:
     DEFAULT_SKILL_EXCEPTION_POLICY = ExceptionPolicyEnum.propagate
     DEFAULT_LOOP_MODE = "async"
     DEFAULT_RUNTIME_MODE = "threaded"
-    DEFAULT_SEARCH_SERVICE_ADDRESS = "oef"
+    DEFAULT_SEARCH_SERVICE_ADDRESS = "fetchai/soef:*"
 
     # pylint: disable=attribute-defined-outside-init
 
@@ -352,10 +346,7 @@ class AEABuilder:
         self._build_called: bool = False
         if not is_full_reset:
             return
-        self._ledger_apis_configs = {}  # type: Dict[str, Dict[str, Union[str, int]]]
-        self._default_ledger = (
-            "fetchai"  # set by the user, or instantiate a default one.
-        )
+        self._default_ledger = DEFAULT_LEDGER
         self._default_connection: PublicId = DEFAULT_CONNECTION
         self._context_namespace = {}  # type: Dict[str, Any]
         self._timeout: Optional[float] = None
@@ -430,7 +421,7 @@ class AEABuilder:
         try:
             _class = getattr(module, class_name)
             self._decision_maker_handler_class = _class
-        except Exception as e:
+        except Exception as e:  # pragma: nocover
             logger.error(
                 "Could not locate decision maker handler for dotted path '{}', class name '{}' and file path '{}'. Error message: {}".format(
                     dotted_path, class_name, file_path, e
@@ -442,7 +433,7 @@ class AEABuilder:
 
     def set_skill_exception_policy(
         self, skill_exception_policy: Optional[ExceptionPolicyEnum]
-    ) -> "AEABuilder":
+    ) -> "AEABuilder":  # pragma: nocover
         """
         Set skill exception policy.
 
@@ -465,10 +456,12 @@ class AEABuilder:
 
         :return: self
         """
-        self._default_routing = default_routing
+        self._default_routing = default_routing  # pragma: nocover
         return self
 
-    def set_loop_mode(self, loop_mode: Optional[str]) -> "AEABuilder":
+    def set_loop_mode(
+        self, loop_mode: Optional[str]
+    ) -> "AEABuilder":  # pragma: nocover
         """
         Set the loop mode.
 
@@ -478,7 +471,9 @@ class AEABuilder:
         self._loop_mode = loop_mode
         return self
 
-    def set_runtime_mode(self, runtime_mode: Optional[str]) -> "AEABuilder":
+    def set_runtime_mode(
+        self, runtime_mode: Optional[str]
+    ) -> "AEABuilder":  # pragma: nocover
         """
         Set the runtime mode.
 
@@ -488,7 +483,9 @@ class AEABuilder:
         self._runtime_mode = runtime_mode
         return self
 
-    def set_search_service_address(self, search_service_address: str) -> "AEABuilder":
+    def set_search_service_address(
+        self, search_service_address: str
+    ) -> "AEABuilder":  # pragma: nocover
         """
         Set the search service address.
 
@@ -533,7 +530,7 @@ class AEABuilder:
         self._check_package_dependencies(configuration)
         self._check_pypi_dependencies(configuration)
 
-    def set_name(self, name: str) -> "AEABuilder":
+    def set_name(self, name: str) -> "AEABuilder":  # pragma: nocover
         """
         Set the name of the agent.
 
@@ -543,7 +540,9 @@ class AEABuilder:
         self._name = name
         return self
 
-    def set_default_connection(self, public_id: PublicId) -> "AEABuilder":
+    def set_default_connection(
+        self, public_id: PublicId
+    ) -> "AEABuilder":  # pragma: nocover
         """
         Set the default connection.
 
@@ -606,33 +605,7 @@ class AEABuilder:
         """Get the connection private key paths."""
         return self._connection_private_key_paths
 
-    def add_ledger_api_config(self, identifier: str, config: Dict) -> "AEABuilder":
-        """
-        Add a configuration for a ledger API to be supported by the agent.
-
-        :param identifier: the identifier of the ledger api
-        :param config: the configuration of the ledger api
-        :return: the AEABuilder
-        """
-        self._ledger_apis_configs[identifier] = config
-        return self
-
-    def remove_ledger_api_config(self, identifier: str) -> "AEABuilder":
-        """
-        Remove a ledger API configuration.
-
-        :param identifier: the identifier of the ledger api
-        :return: the AEABuilder
-        """
-        self._ledger_apis_configs.pop(identifier, None)
-        return self
-
-    @property
-    def ledger_apis_config(self) -> Dict[str, Dict[str, Union[str, int]]]:
-        """Get the ledger api configurations."""
-        return self._ledger_apis_configs
-
-    def set_default_ledger(self, identifier: str) -> "AEABuilder":
+    def set_default_ledger(self, identifier: str) -> "AEABuilder":  # pragma: nocover
         """
         Set a default ledger API to use.
 
@@ -689,7 +662,9 @@ class AEABuilder:
         ] = component
         return self
 
-    def set_context_namespace(self, context_namespace: Dict[str, Any]) -> "AEABuilder":
+    def set_context_namespace(
+        self, context_namespace: Dict[str, Any]
+    ) -> "AEABuilder":  # pragma: nocover
         """Set the context namespace."""
         self._context_namespace = context_namespace
         return self
@@ -1123,13 +1098,13 @@ class AEABuilder:
                 loader = ConfigLoader.from_configuration_type(PackageType.AGENT)
                 agent_configuration = loader.load(fp)
                 logging.config.dictConfig(agent_configuration.logging_config)  # type: ignore
-        except FileNotFoundError:
+        except FileNotFoundError:  # pragma: nocover
             raise Exception(
                 "Agent configuration file '{}' not found in the current directory.".format(
                     DEFAULT_AEA_CONFIG_FILE
                 )
             )
-        except jsonschema.exceptions.ValidationError:
+        except jsonschema.exceptions.ValidationError:  # pragma: nocover
             raise Exception(
                 "Agent configuration file '{}' is invalid. Please check the documentation.".format(
                     DEFAULT_AEA_CONFIG_FILE
@@ -1198,13 +1173,6 @@ class AEABuilder:
                 ledger_identifier, private_key_path, is_connection=True
             )
 
-        # load ledger API configurations
-        for (
-            ledger_identifier,
-            ledger_api_conf,
-        ) in agent_configuration.ledger_apis_dict.items():
-            self.add_ledger_api_config(ledger_identifier, ledger_api_conf)
-
         component_ids = itertools.chain(
             [
                 ComponentId(ComponentType.PROTOCOL, p_id)
@@ -1284,6 +1252,7 @@ class AEABuilder:
 
             if len(configuration.skills) != 0:
                 roots.remove(skill_id)
+
             depends_on[skill_id].update(
                 [
                     ComponentId(ComponentType.SKILL, skill)
@@ -1300,7 +1269,9 @@ class AEABuilder:
         while len(queue) > 0:
             current = queue.pop()
             order.append(current)
-            for node in supports[current]:
+            for node in supports[
+                current
+            ]:  # pragma: nocover # TODO: extract method and test properly
                 depends_on[node].discard(current)
                 if len(depends_on[node]) == 0:
                     queue.append(node)
@@ -1405,7 +1376,7 @@ class AEABuilder:
                     class_kwargs={"contract_interface": contract_interface},
                     contract_config=configuration,  # TODO: resolve configuration being applied globally
                 )
-            except AEAException as e:
+            except AEAException as e:  # pragma: nocover
                 if "Cannot re-register id:" in str(e):
                     logger.warning(
                         "Already registered: {}".format(configuration.class_name)
@@ -1452,7 +1423,7 @@ def _verify_or_create_private_keys(aea_project_path: Path) -> None:
 
     for identifier, _value in agent_configuration.private_key_paths.read_all():
         if identifier not in crypto_registry.supported_ids:
-            ValueError("Unsupported identifier in private key paths.")
+            raise ValueError(f"Item not registered with id '{identifier}'.")
 
     for identifier, private_key_path in IDENTIFIER_TO_KEY_FILES.items():
         config_private_key_path = agent_configuration.private_key_paths.read(identifier)
