@@ -72,7 +72,7 @@ class GenericSearchBehaviour(TickerBehaviour):
         """
         strategy = cast(GenericStrategy, self.context.strategy)
         if strategy.is_searching:
-            query = strategy.get_service_query()
+            query = strategy.get_location_and_service_query()
             oef_search_dialogues = cast(
                 OefSearchDialogues, self.context.oef_search_dialogues
             )
