@@ -21,14 +21,12 @@
 import os
 from unittest import TestCase, mock
 
-from click.testing import CliRunner
-
 import pytest
 
 from aea.cli import cli
 from aea.test_tools.test_cases import AEATestCaseEmpty
 
-from tests.conftest import CLI_LOG_OPTION, MAX_FLAKY_RERUNS
+from tests.conftest import CLI_LOG_OPTION, CliRunner, MAX_FLAKY_RERUNS
 
 
 @mock.patch("aea.cli.utils.decorators.try_to_load_agent_config")
