@@ -25,11 +25,9 @@ import tempfile
 import unittest.mock
 from pathlib import Path
 
-from click.testing import CliRunner
-
 from aea.cli import cli
 
-from tests.conftest import AUTHOR, CLI_LOG_OPTION
+from tests.conftest import AUTHOR, CLI_LOG_OPTION, CliRunner
 
 
 class TestDelete:
