@@ -22,7 +22,6 @@ import os
 from unittest import TestCase, mock
 
 from click import ClickException
-from click.testing import CliRunner
 
 import pytest
 
@@ -30,7 +29,7 @@ from aea.cli import cli
 from aea.cli.fetch import _is_version_correct, fetch_agent_locally
 from aea.test_tools.test_cases import AEATestCaseMany
 
-from tests.conftest import CLI_LOG_OPTION, MAX_FLAKY_RERUNS
+from tests.conftest import CLI_LOG_OPTION, CliRunner, MAX_FLAKY_RERUNS
 from tests.test_cli.tools_for_testing import ContextMock, PublicIdMock
 
 
