@@ -26,13 +26,11 @@ import tempfile
 from pathlib import Path
 from unittest.mock import patch
 
-from click.testing import CliRunner
-
 import yaml
 
 from aea.cli import cli
 
-from tests.conftest import CLI_LOG_OPTION
+from tests.conftest import CLI_LOG_OPTION, CliRunner
 
 
 class TestDoInit:
