@@ -27,7 +27,6 @@ from pathlib import Path
 from unittest import TestCase, mock
 
 from click import ClickException
-from click.testing import CliRunner
 
 import pytest
 
@@ -41,11 +40,12 @@ from aea.configurations.base import (
     PublicId,
 )
 from aea.configurations.constants import DEFAULT_CONNECTION
+from aea.crypto.helpers import FETCHAI_PRIVATE_KEY_FILE
 from aea.exceptions import AEAPackageLoadingError
 from aea.helpers.base import sigint_crossplatform
 
 from tests.common.pexpect_popen import PexpectWrapper
-from tests.conftest import AUTHOR, CLI_LOG_OPTION, MAX_FLAKY_RERUNS, ROOT_DIR
+from tests.conftest import AUTHOR, CLI_LOG_OPTION, CliRunner, MAX_FLAKY_RERUNS, ROOT_DIR
 
 
 if sys.platform.startswith("win"):
@@ -286,7 +286,7 @@ def test_run_unknown_private_key():
         f.write(whole_file)
 
     # Private key needs to exist otherwise doesn't get to code path we are interested in testing
-    with open("fet_private_key.txt", "w") as f:
+    with open(FETCHAI_PRIVATE_KEY_FILE, "w") as f:
         f.write("3801d3703a1fcef18f6bf393fba89245f36b175f4989d8d6e026300dad21e05d")
 
     result = runner.invoke(
@@ -305,82 +305,6 @@ def test_run_unknown_private_key():
         pass
 
 
-# TODO: Test no longer relevant? Current test never exits as check does not throw error
-# def test_run_unknown_ledger():
-#     """Test that the command 'aea run' works as expected."""
-#     runner = CliRunner()
-#     agent_name = "myagent"
-#     cwd = os.getcwd()
-#     t = tempfile.mkdtemp()
-#     # copy the 'packages' directory in the parent of the agent folder.
-#     shutil.copytree(Path(ROOT_DIR, "packages"), Path(t, "packages"))
-
-#     os.chdir(t)
-#     result = runner.invoke(
-#         cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
-#     )
-#     assert result.exit_code == 0
-
-#     result = runner.invoke(cli, [*CLI_LOG_OPTION, "create", "--local", agent_name])
-#     assert result.exit_code == 0
-
-#     os.chdir(Path(t, agent_name))
-
-#     result = runner.invoke(
-#         cli,
-#         [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.5.0"],
-#     )
-#     assert result.exit_code == 0
-#     result = runner.invoke(
-#         cli,
-#         [
-#             *CLI_LOG_OPTION,
-#             "config",
-#             "set",
-#             "agent.default_connection",
-#             "fetchai/http_client:0.5.0",
-#         ],
-#     )
-#     assert result.exit_code == 0
-
-#     # Load the agent yaml file and manually insert the things we need
-#     file = open("aea-config.yaml", mode="r")
-
-#     # read all lines at once
-#     whole_file = file.read()
-
-#     # add in the ledger address
-#     find_text = "ledger_apis: {}"
-#     replace_text = """ledger_apis:
-#     unknown:
-#         address: https://ropsten.infura.io/v3/f00f7b3ba0e848ddbdc8941c527447fe
-#         chain_id: 3
-#         gas_price: 20"""
-
-#     whole_file = whole_file.replace(find_text, replace_text)
-
-#     # close the file
-#     file.close()
-
-#     with open("aea-config.yaml", "w") as f:
-#         f.write(whole_file)
-
-#     result = runner.invoke(
-#         cli,
-#         [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.5.0"],
-#         standalone_mode=False,
-#     )
-
-#     s = "Unsupported identifier unknown in ledger apis."
-#     assert result.exception.message == s
-
-#     os.chdir(cwd)
-#     try:
-#         shutil.rmtree(t)
-#     except (OSError, IOError):
-#         pass
-
-
 def test_run_fet_private_key_config():
     """Test that the command 'aea run' works as expected."""
     runner = CliRunner()
@@ -499,194 +423,6 @@ def test_run_ethereum_private_key_config():
         pass
 
 
-@pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)  # cause ledger depends on network
-def test_run_ledger_apis():
-    """Test that the command 'aea run' works as expected."""
-    runner = CliRunner()
-    agent_name = "myagent"
-    cwd = os.getcwd()
-    t = tempfile.mkdtemp()
-    # copy the 'packages' directory in the parent of the agent folder.
-    shutil.copytree(Path(ROOT_DIR, "packages"), Path(t, "packages"))
-
-    os.chdir(t)
-    result = runner.invoke(
-        cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
-    )
-    assert result.exit_code == 0
-
-    result = runner.invoke(cli, [*CLI_LOG_OPTION, "create", "--local", agent_name])
-    assert result.exit_code == 0
-
-    os.chdir(Path(t, agent_name))
-
-    result = runner.invoke(
-        cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.5.0"],
-    )
-    assert result.exit_code == 0
-    result = runner.invoke(
-        cli,
-        [
-            *CLI_LOG_OPTION,
-            "config",
-            "set",
-            "agent.default_connection",
-            "fetchai/http_client:0.5.0",
-        ],
-    )
-    assert result.exit_code == 0
-
-    # Load the agent yaml file and manually insert the things we need
-    file = open("aea-config.yaml", mode="r")
-
-    # read all lines at once
-    whole_file = file.read()
-
-    # add in the ledger address
-    find_text = "ledger_apis: {}"
-    replace_text = """ledger_apis:
-    ethereum:
-        address: https://ropsten.infura.io/v3/f00f7b3ba0e848ddbdc8941c527447fe
-        chain_id: 3
-        gas_price: 20
-    fetchai:
-        network: testnet"""
-
-    whole_file = whole_file.replace(find_text, replace_text)
-
-    # close the file
-    file.close()
-
-    with open("aea-config.yaml", "w") as f:
-        f.write(whole_file)
-
-    try:
-        process = subprocess.Popen(  # nosec
-            [
-                sys.executable,
-                "-m",
-                "aea.cli",
-                "run",
-                "--connections",
-                "fetchai/http_client:0.5.0",
-            ],
-            stdout=subprocess.PIPE,
-            env=os.environ.copy(),
-        )
-
-        time.sleep(10.0)
-        sigint_crossplatform(process)
-        process.wait(timeout=20)
-
-        assert process.returncode == 0
-
-    finally:
-        poll = process.poll()
-        if poll is None:
-            process.terminate()
-            process.wait(2)
-
-        os.chdir(cwd)
-
-        try:
-            shutil.rmtree(t)
-        except (OSError, IOError):
-            pass
-
-
-@pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)  # cause ledger depends on network
-def test_run_fet_ledger_apis():
-    """Test that the command 'aea run' works as expected."""
-    runner = CliRunner()
-    agent_name = "myagent"
-    cwd = os.getcwd()
-    t = tempfile.mkdtemp()
-    # copy the 'packages' directory in the parent of the agent folder.
-    shutil.copytree(Path(ROOT_DIR, "packages"), Path(t, "packages"))
-
-    os.chdir(t)
-    result = runner.invoke(
-        cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
-    )
-    assert result.exit_code == 0
-
-    result = runner.invoke(cli, [*CLI_LOG_OPTION, "create", "--local", agent_name])
-    assert result.exit_code == 0
-
-    os.chdir(Path(t, agent_name))
-
-    result = runner.invoke(
-        cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.5.0"],
-    )
-    assert result.exit_code == 0
-    result = runner.invoke(
-        cli,
-        [
-            *CLI_LOG_OPTION,
-            "config",
-            "set",
-            "agent.default_connection",
-            "fetchai/http_client:0.5.0",
-        ],
-    )
-    assert result.exit_code == 0
-
-    # Load the agent yaml file and manually insert the things we need
-    file = open("aea-config.yaml", mode="r")
-
-    # read all lines at once
-    whole_file = file.read()
-
-    # add in the ledger address
-
-    find_text = "ledger_apis: {}"
-    replace_text = """ledger_apis:
-    fetchai:
-        network: testnet"""
-
-    whole_file = whole_file.replace(find_text, replace_text)
-
-    # close the file
-    file.close()
-
-    with open("aea-config.yaml", "w") as f:
-        f.write(whole_file)
-
-    try:
-        process = subprocess.Popen(  # nosec
-            [
-                sys.executable,
-                "-m",
-                "aea.cli",
-                "run",
-                "--connections",
-                "fetchai/http_client:0.5.0",
-            ],
-            stdout=subprocess.PIPE,
-            env=os.environ.copy(),
-        )
-
-        time.sleep(10.0)
-        sigint_crossplatform(process)
-        process.wait(timeout=20)
-
-        assert process.returncode == 0
-
-    finally:
-        poll = process.poll()
-        if poll is None:
-            process.terminate()
-            process.wait(2)
-
-        os.chdir(cwd)
-        try:
-            shutil.rmtree(t)
-        except (OSError, IOError):
-            pass
-
-
 @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)  # install depends on network
 def test_run_with_install_deps():
     """Test that the command 'aea run --install-deps' does not crash."""
