@@ -38,6 +38,7 @@ from aea.cli.utils.config import (
 from aea.cli.utils.context import Context
 from aea.cli.utils.decorators import _validate_config_consistency, clean_after
 from aea.cli.utils.formatting import format_items
+from aea.cli.utils.generic import is_readme_present
 from aea.cli.utils.package_utils import (
     find_item_in_distribution,
     find_item_locally,
@@ -49,6 +50,7 @@ from aea.cli.utils.package_utils import (
     validate_package_name,
 )
 
+from tests.conftest import FETCHAI
 from tests.test_cli.tools_for_testing import (
     ConfigLoaderMock,
     ContextMock,
@@ -405,9 +407,17 @@ class TryGetBalanceTestCase(TestCase):
     def test_try_get_balance_positive(self):
         """Test for try_get_balance method positive result."""
         agent_config = mock.Mock()
-        ledger_apis = {"type_": {"address": "some-adress"}}
-        agent_config.ledger_apis_dict = ledger_apis
+        agent_config.default_ledger_config = FETCHAI
 
         wallet_mock = mock.Mock()
-        wallet_mock.addresses = {"type_": "some-adress"}
-        try_get_balance(agent_config, wallet_mock, "type_")
+        wallet_mock.addresses = {FETCHAI: "some-adress"}
+        try_get_balance(agent_config, wallet_mock, FETCHAI)
+
+
+@mock.patch("aea.cli.utils.generic.os.path.exists", return_value=True)
+class IsReadmePresentTestCase(TestCase):
+    """Test case for is_readme_present method."""
+
+    def test_is_readme_present_positive(self, *mocks):
+        """Test is_readme_present for positive result."""
+        self.assertTrue(is_readme_present("readme/path"))
