@@ -27,8 +27,8 @@ from typing import cast
 from aea import AEA_DIR
 from aea.aea import AEA
 from aea.configurations.base import ConnectionConfig, PublicId
-from aea.crypto.fetchai import FetchAICrypto
-from aea.crypto.helpers import FETCHAI_PRIVATE_KEY_FILE, create_private_key
+from aea.crypto.cosmos import CosmosCrypto
+from aea.crypto.helpers import COSMOS_PRIVATE_KEY_FILE, create_private_key
 from aea.crypto.wallet import Wallet
 from aea.identity.base import Identity
 from aea.protocols.base import Protocol
@@ -36,11 +36,16 @@ from aea.registries.resources import Resources
 from aea.skills.base import Skill
 
 from packages.fetchai.connections.ledger.connection import LedgerConnection
-from packages.fetchai.connections.oef.connection import OEFConnection
+from packages.fetchai.connections.p2p_libp2p.connection import P2PLibp2pConnection
+from packages.fetchai.connections.soef.connection import SOEFConnection
 from packages.fetchai.skills.weather_client.strategy import Strategy
 
-HOST = "127.0.0.1"
-PORT = 10000
+API_KEY = "TwiCIriSl0mLahw17pyqoA"
+SOEF_ADDR = "soef.fetch.ai"
+SOEF_PORT = 9002
+ENTRY_PEER_ADDRESS = (
+    "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmAzvu5uNbcnD2qaqrkSULhJsc6GJUg3iikWerJkoD72pr"
+)
 ROOT_DIR = os.getcwd()
 
 logger = logging.getLogger("aea")
@@ -49,20 +54,22 @@ logging.basicConfig(stream=sys.stdout, level=logging.INFO)
 
 def run():
     # Create a private key
-    create_private_key(FetchAICrypto.identifier)
+    create_private_key(CosmosCrypto.identifier)
 
     # Set up the wallet, identity and (empty) resources
-    wallet = Wallet({FetchAICrypto.identifier: FETCHAI_PRIVATE_KEY_FILE})
-    identity = Identity(
-        "my_aea", address=wallet.addresses.get(FetchAICrypto.identifier)
+    wallet = Wallet(
+        private_key_paths={CosmosCrypto.identifier: COSMOS_PRIVATE_KEY_FILE},
+        connection_private_key_paths={CosmosCrypto.identifier: COSMOS_PRIVATE_KEY_FILE},
     )
+    identity = Identity("my_aea", address=wallet.addresses.get(CosmosCrypto.identifier))
     resources = Resources()
 
     # specify the default routing for some protocols
     default_routing = {
-        PublicId.from_str("fetchai/ledger_api:0.1.0"): LedgerConnection.connection_id
+        PublicId.from_str("fetchai/ledger_api:0.1.0"): LedgerConnection.connection_id,
+        PublicId.from_str("fetchai/oef_search:0.3.0"): SOEFConnection.connection_id,
     }
-    default_connection = OEFConnection.connection_id
+    default_connection = SOEFConnection.connection_id
 
     # create the AEA
     my_aea = AEA(
@@ -106,12 +113,37 @@ def run():
     )
     resources.add_connection(ledger_api_connection)
 
-    # Add the OEF connection
+    # Add the P2P connection
     configuration = ConnectionConfig(
-        addr=HOST, port=PORT, connection_id=OEFConnection.connection_id
+        connection_id=P2PLibp2pConnection.connection_id,
+        delegate_uri="127.0.0.1:11001",
+        entry_peers=[ENTRY_PEER_ADDRESS],
+        local_uri="127.0.0.1:9001",
+        log_file="libp2p_node.log",
+        public_uri="127.0.0.1:9001",
     )
-    oef_connection = OEFConnection(configuration=configuration, identity=identity)
-    resources.add_connection(oef_connection)
+    p2p_connection = P2PLibp2pConnection(
+        configuration=configuration,
+        identity=identity,
+        crypto_store=wallet.connection_cryptos,
+    )
+    resources.add_connection(p2p_connection)
+
+    # Add the SOEF connection
+    configuration = ConnectionConfig(
+        api_key=API_KEY,
+        soef_addr=SOEF_ADDR,
+        soef_port=SOEF_PORT,
+        restricted_to_protocols={PublicId.from_str("fetchai/oef_search:0.3.0")},
+        connection_id=SOEFConnection.connection_id,
+        delegate_uri="127.0.0.1:11001",
+        entry_peers=[ENTRY_PEER_ADDRESS],
+        local_uri="127.0.0.1:9001",
+        log_file="libp2p_node.log",
+        public_uri="127.0.0.1:9001",
+    )
+    soef_connection = SOEFConnection(configuration=configuration, identity=identity)
+    resources.add_connection(soef_connection)
 
     # Add the error and weather_client skills
     error_skill = Skill.from_dir(
