@@ -29,8 +29,8 @@ from packages.fetchai.protocols.fipa.message import FipaMessage
 from packages.fetchai.protocols.oef_search.custom_types import OefErrorOperation
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 
-from .helper import compare_enum_classes, compile_and_exec
-from ..conftest import ROOT_DIR
+from tests.conftest import ROOT_DIR
+from tests.test_docs.helper import compare_enum_classes, compile_and_exec
 
 
 class TestProtocolDocs:
