@@ -23,13 +23,22 @@ import filecmp
 import os
 from pathlib import Path
 
+import pytest
+
 from aea import AEA_DIR
 from aea.configurations.base import DEFAULT_VERSION
-from aea.test_tools.test_cases import AEATestCaseMany, UseOef
+from aea.test_tools.test_cases import AEATestCaseMany
 
 from tests.conftest import (
     AUTHOR,
+    COSMOS,
+    COSMOS_PRIVATE_KEY_FILE,
+    FUNDED_COSMOS_PRIVATE_KEY_1,
+    MAX_FLAKY_RERUNS_INTEGRATION,
+    NON_FUNDED_COSMOS_PRIVATE_KEY_1,
+    NON_GENESIS_CONFIG,
     ROOT_DIR,
+    wait_for_localhost_ports_to_close,
 )
 from tests.test_docs.helper import extract_code_blocks
 
@@ -37,7 +46,8 @@ from tests.test_docs.helper import extract_code_blocks
 MD_FILE = "docs/skill-guide.md"
 
 
-class TestBuildSkill(AEATestCaseMany, UseOef):
+@pytest.mark.integration
+class TestBuildSkill(AEATestCaseMany):
     """This class contains the tests for the code-blocks in the skill-guide.md file."""
 
     @classmethod
@@ -51,14 +61,27 @@ class TestBuildSkill(AEATestCaseMany, UseOef):
         """Teat that the md file is not empty."""
         assert self.code_blocks != [], "File must not be empty."
 
+    @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS_INTEGRATION)
     def test_update_skill_and_run(self):
         """Test that the resource folder contains scaffold handlers.py module."""
         self.initialize_aea(AUTHOR)
 
         simple_service_registration_aea = "simple_service_registration"
         self.fetch_agent(
-            "fetchai/simple_service_registration:0.7.0", simple_service_registration_aea
+            "fetchai/simple_service_registration:0.8.0", simple_service_registration_aea
         )
+        self.set_agent_context(simple_service_registration_aea)
+        # add non-funded key
+        self.generate_private_key(COSMOS)
+        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE, connection=True)
+        self.replace_private_key_in_file(
+            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE
+        )
+
+        default_routing = {
+            "fetchai/oef_search:0.3.0": "fetchai/soef:0.5.0",
+        }
 
         search_aea = "search_aea"
         self.create_agents(search_aea)
@@ -66,8 +89,11 @@ class TestBuildSkill(AEATestCaseMany, UseOef):
         skill_name = "my_search"
         skill_id = AUTHOR + "/" + skill_name + ":" + DEFAULT_VERSION
         self.scaffold_item("skill", skill_name)
-        self.add_item("connection", "fetchai/oef:0.6.0")
-        self.set_config("agent.default_connection", "fetchai/oef:0.6.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.5.0")
+        self.add_item("connection", "fetchai/soef:0.5.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.5.0")
+        setting_path = "agent.default_routing"
+        self.force_set_config(setting_path, default_routing)
 
         # manually change the files:
         path = Path(self.t, search_aea, "skills", skill_name, "behaviours.py")
@@ -83,7 +109,13 @@ class TestBuildSkill(AEATestCaseMany, UseOef):
             file.write(self.code_blocks[1])  # block two is handler
 
         path = Path(self.t, search_aea, "skills", skill_name, "my_model.py")
-        os.remove(path)
+        original = Path(AEA_DIR, "skills", "scaffold", "my_model.py")
+        assert filecmp.cmp(path, original)
+        with open(path, "w") as file:
+            file.write(self.code_blocks[2])  # block three is dialogues
+
+        path_new = Path(self.t, search_aea, "skills", skill_name, "dialogues.py")
+        os.rename(path, path_new)
 
         path = Path(self.t, search_aea, "skills", skill_name, "skill.yaml")
         yaml_code_block = extract_code_blocks(self.doc_path, filter="yaml")
@@ -93,18 +125,61 @@ class TestBuildSkill(AEATestCaseMany, UseOef):
         # update fingerprint
         self.fingerprint_item("skill", skill_id)
 
+        # add funded key
+        self.generate_private_key(COSMOS)
+        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE)
+        self.add_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE, connection=True)
+        self.replace_private_key_in_file(
+            FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE
+        )
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
+        self.force_set_config(setting_path, NON_GENESIS_CONFIG)
+
         # run agents
         self.set_agent_context(simple_service_registration_aea)
-        simple_service_registration_aea_process = self.run_agent(
-            "--connections", "fetchai/oef:0.6.0"
+        simple_service_registration_aea_process = self.run_agent()
+
+        check_strings = (
+            "Downloading golang dependencies. This may take a while...",
+            "Finished downloading golang dependencies.",
+            "Starting libp2p node...",
+            "Connecting to libp2p node...",
+            "Successfully connected to libp2p node!",
+            "My libp2p addresses:",
+        )
+        missing_strings = self.missing_from_output(
+            simple_service_registration_aea_process,
+            check_strings,
+            timeout=240,
+            is_terminating=False,
+        )
+        assert (
+            missing_strings == []
+        ), "Strings {} didn't appear in simple_service_registration_aea output.".format(
+            missing_strings
         )
 
         self.set_agent_context(search_aea)
-        search_aea_process = self.run_agent("--connections", "fetchai/oef:0.6.0")
+        search_aea_process = self.run_agent()
 
         check_strings = (
-            "updating services on OEF service directory.",
-            "unregistering services from OEF service directory.",
+            "Downloading golang dependencies. This may take a while...",
+            "Finished downloading golang dependencies.",
+            "Starting libp2p node...",
+            "Connecting to libp2p node...",
+            "Successfully connected to libp2p node!",
+            "My libp2p addresses:",
+        )
+        missing_strings = self.missing_from_output(
+            search_aea_process, check_strings, timeout=240, is_terminating=False
+        )
+        assert (
+            missing_strings == []
+        ), "Strings {} didn't appear in search_aea output.".format(missing_strings)
+
+        check_strings = (
+            "registering agent on SOEF.",
+            "registering service on SOEF.",
         )
         missing_strings = self.missing_from_output(
             simple_service_registration_aea_process,
@@ -135,3 +210,4 @@ class TestBuildSkill(AEATestCaseMany, UseOef):
         assert (
             self.is_successfully_terminated()
         ), "Agents weren't successfully terminated."
+        wait_for_localhost_ports_to_close([9000, 9001])
