@@ -29,8 +29,6 @@ from threading import Thread
 from typing import Optional
 from unittest import TestCase, mock
 
-from click.testing import CliRunner
-
 import pytest
 
 from aea.aea_builder import AEABuilder
@@ -41,7 +39,7 @@ from aea.configurations.base import (
     PublicId,
     SkillConfig,
 )
-from aea.crypto.fetchai import FetchAICrypto
+from aea.configurations.constants import DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_FILE
 from aea.crypto.helpers import create_private_key
 from aea.mail.base import Envelope
 from aea.protocols.base import Message
@@ -56,7 +54,7 @@ from aea.protocols.generator.extract_specification import (
 from aea.skills.base import Handler, Skill, SkillContext
 from aea.test_tools.test_cases import UseOef
 
-from tests.conftest import ROOT_DIR
+from tests.conftest import CliRunner, ROOT_DIR
 from tests.data.generator.t_protocol.message import (  # type: ignore
     TProtocolMessage,
 )
@@ -80,10 +78,10 @@ class TestEndToEndGenerator(UseOef):
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
-        cls.private_key_path_1 = os.path.join(cls.t, FetchAICrypto.identifier + "1")
-        cls.private_key_path_2 = os.path.join(cls.t, FetchAICrypto.identifier + "2")
-        create_private_key("fetchai", cls.private_key_path_1)
-        create_private_key("fetchai", cls.private_key_path_2)
+        cls.private_key_path_1 = os.path.join(cls.t, DEFAULT_PRIVATE_KEY_FILE + "_1")
+        cls.private_key_path_2 = os.path.join(cls.t, DEFAULT_PRIVATE_KEY_FILE + "_2")
+        create_private_key(DEFAULT_LEDGER, cls.private_key_path_1)
+        create_private_key(DEFAULT_LEDGER, cls.private_key_path_2)
 
     def test_compare_latest_generator_output_with_test_protocol(self):
         """Test that the "t_protocol" test protocol matches with what the latest generator generates based on the specification."""
@@ -235,8 +233,8 @@ class TestEndToEndGenerator(UseOef):
         agent_name_2 = "my_aea_2"
         builder_1 = AEABuilder()
         builder_1.set_name(agent_name_1)
-        builder_1.add_private_key(FetchAICrypto.identifier, self.private_key_path_1)
-        builder_1.set_default_ledger(FetchAICrypto.identifier)
+        builder_1.add_private_key(DEFAULT_LEDGER, self.private_key_path_1)
+        builder_1.set_default_ledger(DEFAULT_LEDGER)
         builder_1.set_default_connection(PublicId.from_str("fetchai/oef:0.6.0"))
         builder_1.add_protocol(
             Path(ROOT_DIR, "packages", "fetchai", "protocols", "fipa")
@@ -255,8 +253,8 @@ class TestEndToEndGenerator(UseOef):
 
         builder_2 = AEABuilder()
         builder_2.set_name(agent_name_2)
-        builder_2.add_private_key(FetchAICrypto.identifier, self.private_key_path_2)
-        builder_2.set_default_ledger(FetchAICrypto.identifier)
+        builder_2.add_private_key(DEFAULT_LEDGER, self.private_key_path_2)
+        builder_2.set_default_ledger(DEFAULT_LEDGER)
         builder_2.add_protocol(
             Path(ROOT_DIR, "packages", "fetchai", "protocols", "fipa")
         )
